==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/ResourceStatementRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ResourceStatementRequest(
    resources: Optional[Iterable[String]] = Optional.Absent,
    resourceTypes: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ResourceStatementRequest = {
    import ResourceStatementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
      .builder()
      .optionallyWith(
        resources.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.resources)
      .optionallyWith(
        resourceTypes.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.resourceTypes)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ResourceStatementRequest.ReadOnly =
    zio.aws.ec2.model.ResourceStatementRequest.wrap(buildAwsValue())
}
object ResourceStatementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ResourceStatementRequest =
      zio.aws.ec2.model.ResourceStatementRequest(
        resources.map(value => value),
        resourceTypes.map(value => value)
      )
    def resources: Optional[List[String]]
    def resourceTypes: Optional[List[String]]
    def getResources: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("resources", resources)
    def getResourceTypes: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("resourceTypes", resourceTypes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
  ) extends zio.aws.ec2.model.ResourceStatementRequest.ReadOnly {
    override val resources: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.resources())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val resourceTypes: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceTypes())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
  ): zio.aws.ec2.model.ResourceStatementRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.157.2-sources.jar: zio/aws/ec2/model/ResourceStatementRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ResourceStatementRequest(
    resources: Option[Iterable[String]] = None,
    resourceTypes: Option[Iterable[String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ResourceStatementRequest = {
    import ResourceStatementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
      .builder()
      .optionallyWith(
        resources.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.resources)
      .optionallyWith(
        resourceTypes.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.resourceTypes)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ResourceStatementRequest.ReadOnly =
    zio.aws.ec2.model.ResourceStatementRequest.wrap(buildAwsValue())
}
object ResourceStatementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ResourceStatementRequest =
      zio.aws.ec2.model.ResourceStatementRequest(
        resources.map(value => value),
        resourceTypes.map(value => value)
      )
    def resources: Option[List[String]]
    def resourceTypes: Option[List[String]]
    def getResources: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("resources", resources)
    def getResourceTypes: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("resourceTypes", resourceTypes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
  ) extends zio.aws.ec2.model.ResourceStatementRequest.ReadOnly {
    override val resources: Option[List[String]] = scala
      .Option(impl.resources())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val resourceTypes: Option[List[String]] = scala
      .Option(impl.resourceTypes())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ResourceStatementRequest
  ): zio.aws.ec2.model.ResourceStatementRequest.ReadOnly = new Wrapper(impl)
}
